<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>ActionPackInternal</name>
    <message>
        <location filename="../actions/actionpackinternal/actionpackinternal.h" line="77"/>
        <source>Internal actions</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Actions::BeginProcedureDefinition</name>
    <message>
        <location filename="../actions/actionpackinternal/actions/beginproceduredefinition.h" line="44"/>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/beginproceduredefinition.h" line="45"/>
        <source>The name of the procedure</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Actions::CallProcedureDefinition</name>
    <message>
        <location filename="../actions/actionpackinternal/actions/callproceduredefinition.h" line="44"/>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/callproceduredefinition.h" line="45"/>
        <source>The name of the procedure to call</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Actions::CodeDefinition</name>
    <message>
        <location filename="../actions/actionpackinternal/actions/codedefinition.h" line="44"/>
        <source>Code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/codedefinition.h" line="45"/>
        <source>The code to evaluate</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Actions::ConsoleDefinition</name>
    <message>
        <location filename="../actions/actionpackinternal/actions/consoledefinition.h" line="47"/>
        <source>Text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/consoledefinition.h" line="48"/>
        <source>The text to write</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/consoledefinition.h" line="51"/>
        <source>Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/consoledefinition.h" line="52"/>
        <source>The console output</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Actions::EndProcedureInstance</name>
    <message>
        <location filename="../actions/actionpackinternal/actions/endprocedureinstance.h" line="43"/>
        <source>End procedure reached without a call</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Actions::GotoDefinition</name>
    <message>
        <location filename="../actions/actionpackinternal/actions/gotodefinition.h" line="44"/>
        <source>Line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/gotodefinition.h" line="45"/>
        <source>The line (or label) to go to</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Actions::LoopDefinition</name>
    <message>
        <location filename="../actions/actionpackinternal/actions/loopdefinition.h" line="47"/>
        <source>Line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/loopdefinition.h" line="48"/>
        <source>The line (or label) to go to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/loopdefinition.h" line="51"/>
        <source>Count</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/loopdefinition.h" line="52"/>
        <source>The amount of times (evaluated the first time)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Actions::PauseDefinition</name>
    <message>
        <location filename="../actions/actionpackinternal/actions/pausedefinition.h" line="49"/>
        <source>Duration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/pausedefinition.h" line="50"/>
        <source>The duration of the pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/pausedefinition.h" line="56"/>
        <source>Unit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/pausedefinition.h" line="57"/>
        <source>The pause duration unit</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Actions::PauseInstance</name>
    <message>
        <location filename="../actions/actionpackinternal/actions/pauseinstance.h" line="66"/>
        <source>Invalid pause duration</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Actions::TimeConditionDefinition</name>
    <message>
        <location filename="../actions/actionpackinternal/actions/timeconditiondefinition.h" line="45"/>
        <source>Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/timeconditiondefinition.h" line="46"/>
        <source>The date to compare</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/timeconditiondefinition.h" line="49"/>
        <source>If in the past</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/timeconditiondefinition.h" line="50"/>
        <source>What to do if the date is in the past</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/timeconditiondefinition.h" line="53"/>
        <source>If now</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/timeconditiondefinition.h" line="54"/>
        <source>What to do if the date is the current date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/timeconditiondefinition.h" line="57"/>
        <source>If in the future</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/timeconditiondefinition.h" line="58"/>
        <source>What to do if the date is in the future</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Actions::TimeConditionInstance</name>
    <message>
        <location filename="../actions/actionpackinternal/actions/timeconditioninstance.h" line="49"/>
        <source>Invalid date</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Actions::VariableConditionDefinition</name>
    <message>
        <location filename="../actions/actionpackinternal/actions/variableconditiondefinition.h" line="49"/>
        <source>Variable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/variableconditiondefinition.h" line="51"/>
        <source>The variable to compare</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/variableconditiondefinition.h" line="54"/>
        <source>Comparison</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/variableconditiondefinition.h" line="55"/>
        <source>The comparison</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/variableconditiondefinition.h" line="60"/>
        <source>Value</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/variableconditiondefinition.h" line="61"/>
        <source>The value</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/variableconditiondefinition.h" line="64"/>
        <source>If true</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/variableconditiondefinition.h" line="65"/>
        <source>What to do if the comparison result is true</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/variableconditiondefinition.h" line="68"/>
        <source>If false</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/variableconditiondefinition.h" line="69"/>
        <source>What to do if the comparison result is false</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Actions::VariableConditionInstance</name>
    <message>
        <location filename="../actions/actionpackinternal/actions/variableconditioninstance.h" line="70"/>
        <source>Invalid variable</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Actions::VariableDefinition</name>
    <message>
        <location filename="../actions/actionpackinternal/actions/variabledefinition.h" line="51"/>
        <source>Variable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/variabledefinition.h" line="53"/>
        <source>The variable name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/variabledefinition.h" line="56"/>
        <source>Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/variabledefinition.h" line="57"/>
        <source>The variable type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/variabledefinition.h" line="70"/>
        <source>Value</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/variabledefinition.h" line="71"/>
        <location filename="../actions/actionpackinternal/actions/variabledefinition.h" line="83"/>
        <location filename="../actions/actionpackinternal/actions/variabledefinition.h" line="95"/>
        <source>The variables new value</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/variabledefinition.h" line="82"/>
        <source>Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/variabledefinition.h" line="94"/>
        <source>Position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/variabledefinition.h" line="100"/>
        <source>Conversion failed</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Actions::VariableInstance</name>
    <message>
        <location filename="../actions/actionpackinternal/actions/variableinstance.h" line="83"/>
        <source>Cannot evaluate the value as an integer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/variableinstance.h" line="94"/>
        <source>Cannot evaluate the value as a floating number</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConsoleInstance::outputs</name>
    <message>
        <location filename="../actions/actionpackinternal/actions/consoleinstance.cpp" line="28"/>
        <source>Information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/consoleinstance.cpp" line="29"/>
        <source>Warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/consoleinstance.cpp" line="30"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PauseInstance::units</name>
    <message>
        <location filename="../actions/actionpackinternal/actions/pauseinstance.cpp" line="28"/>
        <source>Milliseconds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/pauseinstance.cpp" line="29"/>
        <source>Seconds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/pauseinstance.cpp" line="30"/>
        <source>Minutes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/pauseinstance.cpp" line="31"/>
        <source>Hours</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/pauseinstance.cpp" line="32"/>
        <source>Days</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../actions/actionpackinternal/actions/beginproceduredefinition.h" line="50"/>
        <source>Begin procedure</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/beginproceduredefinition.h" line="53"/>
        <source>Declares a new procedure</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/callproceduredefinition.h" line="49"/>
        <source>Call procedure</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/callproceduredefinition.h" line="52"/>
        <source>Calls a procedure</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/codedefinition.h" line="50"/>
        <source>Code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/codedefinition.h" line="53"/>
        <source>Evaluates some code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/consoledefinition.h" line="58"/>
        <source>Console</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/consoledefinition.h" line="61"/>
        <source>Write an entry in the console</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/endproceduredefinition.h" line="45"/>
        <source>End procedure</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/endproceduredefinition.h" line="48"/>
        <source>Ends a procedure</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/exitdefinition.h" line="45"/>
        <source>Exit Actiona</source>
        <comment>action name: to exit</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/exitdefinition.h" line="48"/>
        <source>Exit Actiona</source>
        <comment>action description: this exits</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/gotodefinition.h" line="49"/>
        <source>Goto</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/gotodefinition.h" line="52"/>
        <source>Go to a script line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/loopdefinition.h" line="58"/>
        <source>Loop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/loopdefinition.h" line="61"/>
        <source>Go to a script line a specific number of times</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/noopdefinition.h" line="45"/>
        <source>No-op</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/noopdefinition.h" line="48"/>
        <source>Does nothing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/pausedefinition.h" line="63"/>
        <source>Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/pausedefinition.h" line="66"/>
        <source>Pauses the script execution</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/stopdefinition.h" line="45"/>
        <source>Stop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/stopdefinition.h" line="48"/>
        <source>Stop the script execution</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/timeconditiondefinition.h" line="63"/>
        <source>Time condition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/timeconditiondefinition.h" line="66"/>
        <source>Check the current date time and do some action</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/variableconditiondefinition.h" line="73"/>
        <source>Variable condition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/variableconditiondefinition.h" line="76"/>
        <source>Check the value of a variable and do some action</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/variabledefinition.h" line="103"/>
        <source>Variable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/variabledefinition.h" line="106"/>
        <source>Set the value of a variable</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>VariableConditionInstance::comparisons</name>
    <message>
        <location filename="../actions/actionpackinternal/actions/variableconditioninstance.cpp" line="28"/>
        <source>Equal (=)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/variableconditioninstance.cpp" line="29"/>
        <source>Different (!=)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/variableconditioninstance.cpp" line="30"/>
        <source>Inferior (&lt;)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/variableconditioninstance.cpp" line="31"/>
        <source>Superior (&gt;)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/variableconditioninstance.cpp" line="32"/>
        <source>Inferior or equal (&lt;=)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/variableconditioninstance.cpp" line="33"/>
        <source>Superior or equal (&gt;=)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/variableconditioninstance.cpp" line="34"/>
        <source>Contains</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>VariableInstance::types</name>
    <message>
        <location filename="../actions/actionpackinternal/actions/variableinstance.cpp" line="28"/>
        <source>String</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/variableinstance.cpp" line="29"/>
        <source>Integer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/variableinstance.cpp" line="30"/>
        <source>Float</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/variableinstance.cpp" line="31"/>
        <source>Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/variableinstance.cpp" line="32"/>
        <source>Position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/actionpackinternal/actions/variableinstance.cpp" line="33"/>
        <source>Size</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
